@@ -118,6 +118,9 @@ class Config:
 					newfile+=line
 			f.close()
 		else:
+			if not os.path.exists(os.path.expanduser("~")+'/.config'):
+				os.mkdir(os.path.expanduser("~")+'/.config')
+
 			if not os.path.exists(os.path.expanduser("~")+'/.config/pianobar'):
 				os.mkdir(os.path.expanduser("~")+'/.config/pianobar')
 			for opt in self.config_opts:
